Note

Struct Note 

pub struct Note {
    pub freq: f64,
    pub dur: f64,
    pub vol: f32,
    pub wave: WaveForm,
}
This struct represents a note.

It is the building block for all songs made with rs-audio.

use rs_audio::*;

let note: Note = Note {
    freq: 440.0,
    dur: 3.0,
    vol: 0.20,
    wave: WaveForm::Sine,
};

let default_note = Note::default(); // This outputs the same note as the one above.

Fields

freq: f64dur: f64vol: f32wave: WaveForm

Implementations

Source

impl Note

pub fn rest(dur: f64) -> Self

Creates a rest (silence) note.

Usage:

use rs_audio::*;
let rest_note = Note::rest(2.0); // a 2 second rest